import QtQuick 1.1
import com.nokia.meego 1.0
import com.nokia.extras 1.0

Page {
    id: mainPage
    tools: mainTools
   // orientationLock: PageOrientation.LockPortrait

    Component.onCompleted: {
        var info = server.getInfo();
        ipServer.text = info['host'];
        portServer.text = info['port'];
        userServer.text = info['user'];
        passServer.text = info['password'];
        theme.inverted = info['invert']
        settingsPage.setUI(info)
                
		server.error.connect(onConnectionError)
		server.connecting.connect(onServerConnecting)    
		server.clientConnected.connect(onClientConnected)  
    }


    
    function onServerConnecting()
    {
		//sb.text = "Connecting..."
		//sb.show()
		indicator.visible = true;
		indicator.running = true;
    }

    function onConnectionError()
    {
		sb.text = "Unable to connect"
		sb.show()
		connectButton.enabled = true
		//server.disconnectClient()
		indicator.visible = false;
		indicator.running = false;
    }
    
    function onClientConnected()
    {
    	indicator.visible = false;
		indicator.running = false;
        appWindow.pageStack.push(torrentList)
    
    }
    
    function connect(ip, port, usr, pss) {
		server.setInfo(ip, port, usr, pss);
		server.connectClient();	
    
    }
    
	ToolBarLayout {
        id: mainTools
        visible: true
        
        ToolIcon {
			id: connectButton
			platformIconId: "toolbar-done";
            anchors.left: parent.left
            onClicked: {
               //// server.disconnectClient();
                connectButton.enabled = false
                connect(ipServer.text, portServer.text, userServer.text, passServer.text);
  	          }
		}
		        
        ToolIcon {
			platformIconId: "toolbar-view-menu";
            anchors.right: parent===undefined ? undefined : parent.right
            onClicked: (myMenu.status == DialogStatus.Closed) ? myMenu.open() : myMenu.close()
		}
    }
           
   Rectangle {
        id: header
        height: 71
        color: "transparent"
        anchors { left: parent.left; top: parent.top; right: parent.right }

        Image {
            width: header.width; height: header.height
            fillMode: Image.TileHorizontally
            smooth: true
            source: "image://theme/color5-meegotouch-view-header-fixed"
        }
        

        Text {
            x: 16
            width: parent.width - 20
            elide: Text.ElideRight
            font.pixelSize: 32
            color: "white"
            text: qsTr("Transmission Remote")
            anchors.verticalCenter: header.verticalCenter
        }

    }   
    

    Flickable {
        id: settingsFlickable
        anchors.top: header.bottom
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.right: parent.right

        interactive: true
        contentWidth: parent.width
        contentHeight: settingsColumn.height + 30
        clip: true

        Column {
            id: settingsColumn
            spacing: 10
            width: parent.width - 40
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: parent.top
            anchors.topMargin: 20

                Label {
                    text: qsTr("Server")
                    width: parent.width
					height: ipServer.height
					verticalAlignment: Text.AlignVCenter

					TextField {
						id: ipServer
						text: qsTr("192.168.0.8")
						font.pointSize: 20
						anchors.right: parent.right

					}
				}
                Label {
                    text: qsTr("Port")
                    width: parent.width
					height: portServer.height
					verticalAlignment: Text.AlignVCenter

					

					TextField {
						id: portServer
						text: qsTr("9091")
						font.pointSize: 20
						inputMethodHints: Qt.ImhDigitsOnly
						validator: RegExpValidator { regExp: /\d*/ }
						anchors.right: parent.right

					}
				}
				
                Label {
                    text: qsTr("User")
                    width: parent.width
					height: userServer.height
					verticalAlignment: Text.AlignVCenter

					TextField {
						id: userServer
						text: qsTr("admin")
						font.pointSize: 20
						anchors.right: parent.right

					}
				}
                Label {
					id: passLabel
                    text: qsTr("Password")                
                    width: parent.width
					height: passServer.height
					verticalAlignment: Text.AlignVCenter
                

					TextField {
						id: passServer
						echoMode: TextInput.Password
						text: qsTr("admin")
						font.pointSize: 20
						anchors.right: parent.right
					}
                }
                 Item {width:16; height:24}

	
			Row {
                anchors.horizontalCenter:parent.horizontalCenter
			
				 BusyIndicator {
					 id: indicator
					 platformStyle: BusyIndicatorStyle { size: "large" }
					 running:  false
					 visible: false
		
				 }
			}
			}

		
	}
}
