import os
import sys
from PySide.QtCore import QObject, QThread, Signal, Slot, Property, QAbstractListModel, QModelIndex

sys.path.insert(0, "/usr/share/transmissionr")
import transmissionrpc

class TransmissionHelper(QObject):
    def __init__(self, parent=None):
        QObject.__init__(self, parent)
        self.tc = 0
        self.r = 0
        self.controller = Controller()
        self.thingList = 0
        self.sortby = 1
        self.localTorrents = []

    @Slot(str, str, str, str, result=bool)
    def connect(self, a, b, c, d):
		try:
			self.tc = transmissionrpc.Client(address=a, port=b, user=c, password= d)
		except:
			return False
			
		self.update_torrents()
		self.update_list()
  
		return True
		
    @Slot(int)
    def sort_by(self, a):
        self.sortby = a	
        self.update_list()

    @Slot()
    def update_torrents(self):
		self.localTorrents = self.tc.get_torrents()
		self.update_list()
		
    @Slot()
    def update_list(self):	
        self.sort_list()	
        self.things = [ThingWrapper(thing) for thing in self.localTorrents]
        self.thingList.replaceItems(self.things)  
        
    
    @Slot(str)
    def add_url(self, a):
		self.tc.add_uri(a)
		
    def sort_list(self):
        if self.sortby == 1:
            self.localTorrents = sorted(self.localTorrents, key=lambda torrent: torrent.name.lower())
        elif self.sortby == 2:
		    self.localTorrents = sorted(self.localTorrents, key=lambda torrent: torrent.status)
        elif self.sortby == 3:
		    self.localTorrents = sorted(self.localTorrents, key=lambda torrent: torrent.progress)
        elif self.sortby == 4:
            self.localTorrents = sorted(self.localTorrents, key=lambda torrent: torrent.eta)



class Controller(QObject):
	@Slot(QObject)
	def thingSelected(self, wrapper):
		global thelper
		#print wrapper.torrenthash
		print 'User clicked on:', wrapper._thing.id
		print thelper.tc.info(wrapper._thing.id)
		
		
	@Slot(QObject)
	def statusChange(self, wrapper):
		global thelper
		if wrapper._thing.status == "stopped":
			thelper.tc.start(wrapper._thing.id)			
		else:
			thelper.tc.stop(wrapper._thing.id)
		#wrapper._thing.update()	
		#print wrapper._thing.status




class ThingWrapper(QObject):
	def __init__(self, thing):
		QObject.__init__(self)
		self._thing = thing
 
	def _name(self):
		return str(self._thing.name)
 
	def _status(self):
		if self._thing.status == "seeding":
			return "upload"
		elif self._thing.status == "downloading":
			return "download"
		else:
			return "pause"
		
	def _progress(self):
		return str(int(self._thing.progress))
		
	def _hash(self):
		return str("hi")
		
	changed = Signal()
	
	torrenthash =  Property(unicode, _hash, notify=changed)
	name = Property(unicode, _name, notify=changed)
	status = Property(unicode, _status, notify=changed)
	progress = Property(unicode, _progress, notify=changed)


class ThingListModel(QAbstractListModel):
	COLUMNS = ('thing',)
 
	def __init__(self, things):
		QAbstractListModel.__init__(self)
		self._things = things
		self.setRoleNames(dict(enumerate(ThingListModel.COLUMNS)))
 
	def rowCount(self, parent=QModelIndex()):
		return len(self._things)
 
	def data(self, index, role):
		if index.isValid() and role == ThingListModel.COLUMNS.index('thing'):
			return self._things[index.row()]
		return None
		
	def replaceItems(self, items):
		#self.beginRemoveRows(QtCore.QModelIndex(), 0, len(self._things))
		#self.removeRows(0, len(self._things))       
		#self.endRemoveRows() 
		#self.beginInsertRows(QtCore.QModelIndex(), len(self._things), len(self._things))
		self.beginResetModel()
		self._things = items
		self.endResetModel()
		#self.endInsertRows()
		#QObject.emit(self, SIGNAL("dataChanged(const QModelIndex&, const QModelIndex &)"), index, index)

